@@ -444,12 +444,23 @@ def cleaning_error_handler(task, msg, tear_down_cleaning=True,
         task.process_event('fail', target_state=target_state)
 
 
-def wipe_deploy_internal_info(node):
-    """Remove temporary deployment fields from driver_internal_info."""
-    info = node.driver_internal_info
+def wipe_token_and_url(task):
+    """Remove agent URL and token from the task."""
+    info = task.node.driver_internal_info
     info.pop('agent_secret_token', None)
     info.pop('agent_secret_token_pregenerated', None)
+    # Remove agent_url since it will be re-asserted
+    # upon the next deployment attempt.
+    info.pop('agent_url', None)
+    task.node.driver_internal_info = info
+
+
+def wipe_deploy_internal_info(task):
+    """Remove temporary deployment fields from driver_internal_info."""
+    if not fast_track_able(task):
+        wipe_token_and_url(task)
     # Clear any leftover metadata about deployment.
+    info = task.node.driver_internal_info
     info['deploy_steps'] = None
     info.pop('agent_cached_deploy_steps', None)
     info.pop('deploy_step_index', None)
@@ -457,10 +468,22 @@ def wipe_deploy_internal_info(node):
     info.pop('deployment_polling', None)
     info.pop('skip_current_deploy_step', None)
     info.pop('steps_validated', None)
-    # Remove agent_url since it will be re-asserted
-    # upon the next deployment attempt.
-    info.pop('agent_url', None)
-    node.driver_internal_info = info
+    task.node.driver_internal_info = info
+
+
+def wipe_cleaning_internal_info(task):
+    """Remove temporary cleaning fields from driver_internal_info."""
+    if not fast_track_able(task):
+        wipe_token_and_url(task)
+    info = task.node.driver_internal_info
+    info['clean_steps'] = None
+    info.pop('agent_cached_clean_steps', None)
+    info.pop('clean_step_index', None)
+    info.pop('cleaning_reboot', None)
+    info.pop('cleaning_polling', None)
+    info.pop('skip_current_clean_step', None)
+    info.pop('steps_validated', None)
+    task.node.driver_internal_info = info
 
 
 def deploying_error_handler(task, logmsg, errmsg=None, traceback=False,
@@ -503,7 +526,7 @@ def deploying_error_handler(task, logmsg, errmsg=None, traceback=False,
         # Clear deploy step; we leave the list of deploy steps
         # in node.driver_internal_info for debugging purposes.
         node.deploy_step = {}
-        wipe_deploy_internal_info(node)
+        wipe_deploy_internal_info(task)
 
     if cleanup_err:
         node.last_error = cleanup_err
@@ -1047,19 +1070,6 @@ def add_secret_token(node, pregenerated=False):
     node.driver_internal_info = i_info
 
 
-def del_secret_token(node):
-    """Deletes the IPA agent secret token.
-
-    Removes the agent token secret from the driver_internal_info field
-    from the Node object.
-
-    :param node: Node object
-    """
-    i_info = node.driver_internal_info
-    i_info.pop('agent_secret_token', None)
-    node.driver_internal_info = i_info
-
-
 def is_agent_token_present(node):
     """Determines if an agent token is present upon a node.
 
