@@ -29,10 +29,8 @@ import tempfile
 
 import eventlet
 eventlet.monkey_patch(os=False)
-
 import fixtures
 from ironic_lib import utils
-import mock
 from oslo_concurrency import processutils
 from oslo_config import fixture as config_fixture
 from oslo_log import log as logging
@@ -44,6 +42,7 @@ from ironic.common import config as ironic_config
 from ironic.common import context as ironic_context
 from ironic.common import driver_factory
 from ironic.common import hash_ring
+from ironic.common import utils as common_utils
 from ironic.conf import CONF
 from ironic.drivers import base as drivers_base
 from ironic.objects import base as objects_base
@@ -98,27 +97,25 @@ class TestCase(oslo_test_base.BaseTestCase):
         self.useFixture(fixtures.EnvironmentVariable('http_proxy'))
         self.policy = self.useFixture(policy_fixture.PolicyFixture())
 
-        driver_factory.DriverFactory._extension_manager = None
         driver_factory.HardwareTypesFactory._extension_manager = None
         for factory in driver_factory._INTERFACE_LOADERS.values():
             factory._extension_manager = None
 
-        # Block access to utils.execute() and related functions.
-        # NOTE(bigjools): Not using a decorator on tests because I don't
-        # want to force every test method to accept a new arg. Instead, they
-        # can override or examine this self._exec_patch Mock as needed.
+        # Ban running external processes via 'execute' like functions. If the
+        # patched function is called, an exception is raised to warn the
+        # tester.
         if self.block_execute:
-            self._exec_patch = mock.Mock()
-            self._exec_patch.side_effect = Exception(
-                "Don't call ironic_lib.utils.execute() / "
-                "processutils.execute() or similar functions in tests!")
-
-            self.patch(processutils, 'execute', self._exec_patch)
-            self.patch(subprocess, 'Popen', self._exec_patch)
-            self.patch(subprocess, 'call', self._exec_patch)
-            self.patch(subprocess, 'check_call', self._exec_patch)
-            self.patch(subprocess, 'check_output', self._exec_patch)
-            self.patch(utils, 'execute', self._exec_patch)
+            # NOTE(jlvillal): Intentionally not using mock as if you mock a
+            # mock it causes things to not work correctly. As doing an
+            # autospec=True causes strangeness. By using a simple function we
+            # can then mock it without issue.
+            self.patch(processutils, 'execute', do_not_call)
+            self.patch(subprocess, 'call', do_not_call)
+            self.patch(subprocess, 'check_call', do_not_call)
+            self.patch(subprocess, 'check_output', do_not_call)
+            self.patch(utils, 'execute', do_not_call)
+            # subprocess.Popen is a class
+            self.patch(subprocess, 'Popen', DoNotCallPopen)
 
     def _set_config(self):
         self.cfg_fixture = self.useFixture(config_fixture.Config(CONF))
@@ -131,11 +128,29 @@ class TestCase(oslo_test_base.BaseTestCase):
                     group='neutron')
         self.config(rescuing_network=uuidutils.generate_uuid(),
                     group='neutron')
-        self.config(enabled_drivers=['fake'])
-        self.config(enabled_hardware_types=['fake-hardware'])
-        self.config(enabled_network_interfaces=['flat', 'noop', 'neutron'])
+        self.config(enabled_hardware_types=['fake-hardware',
+                                            'manual-management'])
         for iface in drivers_base.ALL_INTERFACES:
-            self.config(**{'default_%s_interface' % iface: None})
+            default = None
+
+            # Restore some reasonable defaults
+            if iface == 'network':
+                values = ['flat', 'noop', 'neutron']
+            else:
+                values = ['fake']
+
+            if iface == 'deploy':
+                values.extend(['iscsi', 'direct'])
+            elif iface == 'boot':
+                values.append('pxe')
+            elif iface == 'storage':
+                default = 'noop'
+                values.append('noop')
+            elif iface not in {'network', 'power', 'management'}:
+                values.append('no-%s' % iface)
+
+            self.config(**{'enabled_%s_interfaces' % iface: values,
+                           'default_%s_interface' % iface: default})
         self.set_defaults(host='fake-mini',
                           debug=True)
         self.set_defaults(connection="sqlite://",
@@ -158,6 +173,12 @@ class TestCase(oslo_test_base.BaseTestCase):
         """Override config options for a test."""
         self.cfg_fixture.config(**kw)
 
+    def config_temp_dir(self, option, group=None):
+        """Override a config option with a temporary directory."""
+        temp_dir = tempfile.mkdtemp()
+        self.addCleanup(lambda: common_utils.rmtree_without_raise(temp_dir))
+        self.config(**{option: temp_dir, 'group': group})
+
     def set_defaults(self, **kw):
         """Set default values of config options."""
         group = kw.pop('group', None)
@@ -201,3 +222,35 @@ class TestCase(oslo_test_base.BaseTestCase):
         self.assertEqual(event_type, notif_args['event_type'].
                          to_event_type_field())
         self.assertEqual(level, notif_args['level'])
+
+
+def do_not_call(*args, **kwargs):
+    """Helper function to raise an exception if it is called"""
+    raise Exception(
+        "Don't call ironic_lib.utils.execute() / "
+        "processutils.execute() or similar functions in tests!")
+
+
+class DoNotCallPopen(object):
+    """Helper class to mimic subprocess.popen()
+
+    It's job is to raise an exception if it is called. We create stub functions
+    so mocks that use autospec=True will work.
+    """
+    def __init__(self, *args, **kwargs):
+        do_not_call(*args, **kwargs)
+
+    def communicate(input=None):
+        pass
+
+    def kill():
+        pass
+
+    def poll():
+        pass
+
+    def terminate():
+        pass
+
+    def wait():
+        pass
