@@ -190,9 +190,10 @@ class TestListChassis(test_api_base.BaseApiTest):
         self.assertIn('links', data)
         self.assertEqual(2, len(data['links']))
         self.assertIn(uuid, data['links'][0]['href'])
-        for l in data['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'], bookmark=bookmark))
+        for link in data['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(self.validate_link(link['href'],
+                            bookmark=bookmark))
 
         if public_url is not None:
             expected = [{'href': '%s/v1/chassis/%s' % (public_url, uuid),
