@@ -14,12 +14,12 @@ Tests for the API /conductors/ methods.
 """
 
 import datetime
+from http import client as http_client
 
 import mock
 from oslo_config import cfg
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
-from six.moves import http_client
 
 from ironic.api.controllers import base as api_base
 from ironic.api.controllers import v1 as api_v1
@@ -156,9 +156,9 @@ class TestListConductors(test_api_base.BaseApiTest):
         self.assertIn('links', data)
         self.assertEqual(2, len(data['links']))
         self.assertIn('rocky.rocks', data['links'][0]['href'])
-        for l in data['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'], bookmark=bookmark,
+        for link in data['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(self.validate_link(link['href'], bookmark=bookmark,
                                                headers=headers))
 
         if public_url is not None:
