@@ -216,9 +216,9 @@ class TestListDeployTemplates(BaseDeployTemplatesAPITest):
         self.assertIn('links', data)
         self.assertEqual(2, len(data['links']))
         self.assertIn(uuid, data['links'][0]['href'])
-        for l in data['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'], bookmark=bookmark,
+        for link in data['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(self.validate_link(link['href'], bookmark=bookmark,
                             headers=self.headers))
 
     def test_collection_links(self):
@@ -655,7 +655,7 @@ class TestPatch(BaseDeployTemplatesAPITest):
     def test_add_root_non_existent(self, mock_save):
         patch = [{'path': '/foo', 'value': 'bar', 'op': 'add'}]
         self._test_update_bad_request(
-            mock_save, patch, "Adding a new attribute \(/foo\)")
+            mock_save, patch, "Adding a new attribute \\(/foo\\)")
 
     def test_add_too_high_index_step_fail(self, mock_save):
         step = {
