@@ -530,11 +530,15 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_clean_step',
                 autospec=True)
     def _do_next_clean_step_last_step_noop(self, mock_execute, manual=False,
-                                           retired=False):
+                                           retired=False, fast_track=False):
+        if fast_track:
+            self.config(fast_track=True, group='deploy')
         # Resume where last_step is the last cleaning step, should be noop
         tgt_prov_state = states.MANAGEABLE if manual else states.AVAILABLE
         info = {'clean_steps': self.clean_steps,
-                'clean_step_index': len(self.clean_steps) - 1}
+                'clean_step_index': len(self.clean_steps) - 1,
+                'agent_url': 'test-url',
+                'agent_secret_token': 'token'}
 
         node = obj_utils.create_test_node(
             self.context, driver='fake-hardware',
@@ -562,6 +566,15 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         self.assertNotIn('clean_step_index', node.driver_internal_info)
         self.assertIsNone(node.driver_internal_info['clean_steps'])
         self.assertFalse(mock_execute.called)
+        if fast_track:
+            self.assertEqual('test-url',
+                             node.driver_internal_info.get('agent_url'))
+            self.assertIsNotNone(
+                node.driver_internal_info.get('agent_secret_token'))
+        else:
+            self.assertNotIn('agent_url', node.driver_internal_info)
+            self.assertNotIn('agent_secret_token',
+                             node.driver_internal_info)
 
     def test__do_next_clean_step_automated_last_step_noop(self):
         self._do_next_clean_step_last_step_noop()
@@ -572,12 +585,17 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
     def test__do_next_clean_step_retired_last_step_change_tgt_state(self):
         self._do_next_clean_step_last_step_noop(retired=True)
 
+    def test__do_next_clean_step_last_step_noop_fast_track(self):
+        self._do_next_clean_step_last_step_noop(fast_track=True)
+
+    @mock.patch('ironic.drivers.utils.collect_ramdisk_logs', autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakePower.execute_clean_step',
                 autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_clean_step',
                 autospec=True)
     def _do_next_clean_step_all(self, mock_deploy_execute,
-                                mock_power_execute, manual=False):
+                                mock_power_execute, mock_collect_logs,
+                                manual=False):
         # Run all steps from start to finish (all synchronous)
         tgt_prov_state = states.MANAGEABLE if manual else states.AVAILABLE
 
@@ -617,6 +635,7 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         mock_deploy_execute.assert_has_calls(
             [mock.call(mock.ANY, mock.ANY, self.clean_steps[0]),
              mock.call(mock.ANY, mock.ANY, self.clean_steps[2])])
+        self.assertFalse(mock_collect_logs.called)
 
     def test_do_next_clean_step_automated_all(self):
         self._do_next_clean_step_all()
@@ -624,11 +643,62 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
     def test_do_next_clean_step_manual_all(self):
         self._do_next_clean_step_all(manual=True)
 
+    @mock.patch('ironic.drivers.utils.collect_ramdisk_logs', autospec=True)
+    @mock.patch('ironic.drivers.modules.fake.FakePower.execute_clean_step',
+                autospec=True)
+    @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_clean_step',
+                autospec=True)
+    def test_do_next_clean_step_collect_logs(self, mock_deploy_execute,
+                                             mock_power_execute,
+                                             mock_collect_logs):
+        CONF.set_override('deploy_logs_collect', 'always', group='agent')
+        # Run all steps from start to finish (all synchronous)
+        tgt_prov_state = states.MANAGEABLE
+
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            provision_state=states.CLEANING,
+            target_provision_state=tgt_prov_state,
+            last_error=None,
+            driver_internal_info={'clean_steps': self.clean_steps,
+                                  'clean_step_index': None},
+            clean_step={})
+
+        def fake_deploy(conductor_obj, task, step):
+            driver_internal_info = task.node.driver_internal_info
+            driver_internal_info['goober'] = 'test'
+            task.node.driver_internal_info = driver_internal_info
+            task.node.save()
+
+        mock_deploy_execute.side_effect = fake_deploy
+        mock_power_execute.return_value = None
+
+        with task_manager.acquire(
+                self.context, node.uuid, shared=False) as task:
+            cleaning.do_next_clean_step(task, 0)
+
+        node.refresh()
+
+        # Cleaning should be complete
+        self.assertEqual(tgt_prov_state, node.provision_state)
+        self.assertEqual(states.NOSTATE, node.target_provision_state)
+        self.assertEqual({}, node.clean_step)
+        self.assertNotIn('clean_step_index', node.driver_internal_info)
+        self.assertEqual('test', node.driver_internal_info['goober'])
+        self.assertIsNone(node.driver_internal_info['clean_steps'])
+        mock_power_execute.assert_called_once_with(mock.ANY, mock.ANY,
+                                                   self.clean_steps[1])
+        mock_deploy_execute.assert_has_calls(
+            [mock.call(mock.ANY, mock.ANY, self.clean_steps[0]),
+             mock.call(mock.ANY, mock.ANY, self.clean_steps[2])])
+        mock_collect_logs.assert_called_once_with(mock.ANY, label='cleaning')
+
+    @mock.patch('ironic.drivers.utils.collect_ramdisk_logs', autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_clean_step',
                 autospec=True)
     @mock.patch.object(fake.FakeDeploy, 'tear_down_cleaning', autospec=True)
     def _do_next_clean_step_execute_fail(self, tear_mock, mock_execute,
-                                         manual=False):
+                                         mock_collect_logs, manual=False):
         # When a clean step fails, go to CLEANFAIL
         tgt_prov_state = states.MANAGEABLE if manual else states.AVAILABLE
 
@@ -658,6 +728,7 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
         self.assertTrue(node.maintenance)
         mock_execute.assert_called_once_with(
             mock.ANY, mock.ANY, self.clean_steps[0])
+        mock_collect_logs.assert_called_once_with(mock.ANY, label='cleaning')
 
     def test__do_next_clean_step_automated_execute_fail(self):
         self._do_next_clean_step_execute_fail()
@@ -833,8 +904,9 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
             self.config(fast_track=True, group='deploy')
 
         for info in ({'clean_steps': None, 'clean_step_index': None,
-                      'agent_url': 'test-url'},
-                     {'clean_steps': None, 'agent_url': 'test-url'}):
+                      'agent_url': 'test-url', 'agent_secret_token': 'magic'},
+                     {'clean_steps': None, 'agent_url': 'test-url',
+                      'agent_secret_token': 'it_is_a_kind_of_magic'}):
             # Resume where there are no steps, should be a noop
             tgt_prov_state = states.MANAGEABLE if manual else states.AVAILABLE
 
@@ -862,8 +934,12 @@ class DoNodeCleanTestCase(db_base.DbTestCase):
             if fast_track:
                 self.assertEqual('test-url',
                                  node.driver_internal_info.get('agent_url'))
+                self.assertIsNotNone(
+                    node.driver_internal_info.get('agent_secret_token'))
             else:
                 self.assertNotIn('agent_url', node.driver_internal_info)
+                self.assertNotIn('agent_secret_token',
+                                 node.driver_internal_info)
             mock_execute.reset_mock()
 
     def test__do_next_clean_step_automated_no_steps(self):
@@ -928,6 +1004,8 @@ class DoNodeCleanAbortTestCase(db_base.DbTestCase):
             target_provision_state=states.AVAILABLE,
             clean_step={'step': 'foo', 'abortable': True},
             driver_internal_info={
+                'agent_url': 'some url',
+                'agent_secret_token': 'token',
                 'clean_step_index': 2,
                 'cleaning_reboot': True,
                 'cleaning_polling': True,
@@ -949,6 +1027,10 @@ class DoNodeCleanAbortTestCase(db_base.DbTestCase):
                              task.node.driver_internal_info)
             self.assertNotIn('skip_current_clean_step',
                              task.node.driver_internal_info)
+            self.assertNotIn('agent_url',
+                             task.node.driver_internal_info)
+            self.assertNotIn('agent_secret_token',
+                             task.node.driver_internal_info)
 
     def test__do_node_clean_abort(self):
         self._test__do_node_clean_abort(None)
