@@ -19,6 +19,7 @@ from oslo_db import exception as db_exception
 from oslo_utils import uuidutils
 
 from ironic.common import exception
+from ironic.common import images
 from ironic.common import states
 from ironic.common import swift
 from ironic.conductor import deployments
@@ -123,7 +124,9 @@ class DoNodeDeployTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
 
     @mock.patch.object(deployments, '_store_configdrive', autospec=True)
     def _test__do_node_deploy_ok(self, mock_store, configdrive=None,
-                                 expected_configdrive=None):
+                                 expected_configdrive=None, fast_track=False):
+        if fast_track:
+            self.config(fast_track=True, group='deploy')
         expected_configdrive = expected_configdrive or configdrive
         self._start_service()
         with mock.patch.object(fake.FakeDeploy,
@@ -132,7 +135,9 @@ class DoNodeDeployTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
             self.node = obj_utils.create_test_node(
                 self.context, driver='fake-hardware', name=None,
                 provision_state=states.DEPLOYING,
-                target_provision_state=states.ACTIVE)
+                target_provision_state=states.ACTIVE,
+                driver_internal_info={'agent_url': 'url',
+                                      'agent_secret_token': 'token'})
             task = task_manager.TaskManager(self.context, self.node.uuid)
 
             deployments.do_node_deploy(task, self.service.conductor.id,
@@ -147,6 +152,12 @@ class DoNodeDeployTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
                                                    expected_configdrive)
             else:
                 self.assertFalse(mock_store.called)
+            self.assertEqual(
+                fast_track,
+                bool(task.node.driver_internal_info.get('agent_url')))
+            self.assertEqual(
+                fast_track,
+                bool(task.node.driver_internal_info.get('agent_secret_token')))
 
     def test__do_node_deploy_ok(self):
         self._test__do_node_deploy_ok()
@@ -155,6 +166,9 @@ class DoNodeDeployTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
         configdrive = 'foo'
         self._test__do_node_deploy_ok(configdrive=configdrive)
 
+    def test__do_node_deploy_fast_track(self):
+        self._test__do_node_deploy_ok(fast_track=True)
+
     @mock.patch('openstack.baremetal.configdrive.build')
     def test__do_node_deploy_configdrive_as_dict(self, mock_cd):
         mock_cd.return_value = 'foo'
@@ -359,6 +373,39 @@ class DoNodeDeployTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
         self.assertIsNotNone(node.last_error)
         self.assertFalse(mock_deploy.called)
 
+    @mock.patch.object(task_manager.TaskManager, 'process_event',
+                       autospec=True)
+    @mock.patch('ironic.drivers.modules.fake.FakePower.validate')
+    @mock.patch('ironic.drivers.modules.fake.FakeDeploy.validate')
+    @mock.patch.object(conductor_steps, 'validate_deploy_templates',
+                       autospec=True)
+    @mock.patch.object(conductor_utils, 'validate_instance_info_traits',
+                       autospec=True)
+    @mock.patch.object(images, 'is_whole_disk_image', autospec=True)
+    def test_start_deploy(self, mock_iwdi, mock_validate_traits,
+                          mock_validate_templates, mock_deploy_validate,
+                          mock_power_validate, mock_process_event):
+        self._start_service()
+        mock_iwdi.return_value = False
+        node = obj_utils.create_test_node(self.context, driver='fake-hardware',
+                                          provision_state=states.AVAILABLE,
+                                          target_provision_state=states.ACTIVE)
+        task = task_manager.TaskManager(self.context, node.uuid)
+
+        deployments.start_deploy(task, self.service, configdrive=None,
+                                 event='deploy')
+        node.refresh()
+        self.assertTrue(mock_iwdi.called)
+        mock_power_validate.assert_called_once_with(task)
+        mock_deploy_validate.assert_called_once_with(task)
+        mock_validate_traits.assert_called_once_with(task.node)
+        mock_validate_templates.assert_called_once_with(
+            task, skip_missing=True)
+        mock_process_event.assert_called_with(
+            mock.ANY, 'deploy', call_args=(
+                deployments.do_node_deploy, task, 1, None),
+            callback=mock.ANY, err_handler=mock.ANY)
+
 
 @mgr_utils.mock_record_keepalive
 class DoNextDeployStepTestCase(mgr_utils.ServiceSetUpMixin,
@@ -410,6 +457,39 @@ class DoNextDeployStepTestCase(mgr_utils.ServiceSetUpMixin,
         mock_execute.assert_called_once_with(mock.ANY, task,
                                              self.deploy_steps[0])
 
+    @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_deploy_step',
+                autospec=True)
+    def test__do_next_deploy_step_in_deploywait(self, mock_execute):
+        driver_internal_info = {'deploy_step_index': None,
+                                'deploy_steps': self.deploy_steps}
+        self._start_service()
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            driver_internal_info=driver_internal_info,
+            deploy_step={})
+
+        def fake_execute(interface, task, step):
+            # A deploy step leaves the node in DEPLOYWAIT
+            task.process_event('wait')
+            return states.DEPLOYWAIT
+
+        mock_execute.side_effect = fake_execute
+        expected_first_step = node.driver_internal_info['deploy_steps'][0]
+        task = task_manager.TaskManager(self.context, node.uuid)
+        task.process_event('deploy')
+
+        deployments.do_next_deploy_step(task, 0, self.service.conductor.id)
+
+        node.refresh()
+        self.assertIsNone(node.last_error)
+        self.assertEqual(states.DEPLOYWAIT, node.provision_state)
+        self.assertEqual(states.ACTIVE, node.target_provision_state)
+        self.assertEqual(expected_first_step, node.deploy_step)
+        self.assertEqual(0, node.driver_internal_info['deploy_step_index'])
+        self.assertEqual(self.service.conductor.id, node.conductor_affinity)
+        mock_execute.assert_called_once_with(mock.ANY, task,
+                                             self.deploy_steps[0])
+
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_deploy_step',
                 autospec=True)
     def test__do_next_deploy_step_continue_from_last_step(self, mock_execute):
@@ -494,7 +574,8 @@ class DoNextDeployStepTestCase(mgr_utils.ServiceSetUpMixin,
         # Run all steps from start to finish (all synchronous)
         driver_internal_info = {'deploy_step_index': None,
                                 'deploy_steps': self.deploy_steps,
-                                'agent_url': 'url'}
+                                'agent_url': 'url',
+                                'agent_secret_token': 'token'}
         self._start_service()
         node = obj_utils.create_test_node(
             self.context, driver='fake-hardware',
@@ -517,6 +598,41 @@ class DoNextDeployStepTestCase(mgr_utils.ServiceSetUpMixin,
         mock_execute.assert_has_calls = [mock.call(self.deploy_steps[0]),
                                          mock.call(self.deploy_steps[1])]
         self.assertNotIn('agent_url', node.driver_internal_info)
+        self.assertNotIn('agent_secret_token', node.driver_internal_info)
+
+    @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_deploy_step',
+                autospec=True)
+    def test__do_next_deploy_step_fast_track(self, mock_execute):
+        self.config(fast_track=True, group='deploy')
+        # Run all steps from start to finish (all synchronous)
+        driver_internal_info = {'deploy_step_index': None,
+                                'deploy_steps': self.deploy_steps,
+                                'agent_url': 'url',
+                                'agent_secret_token': 'token'}
+        self._start_service()
+        node = obj_utils.create_test_node(
+            self.context, driver='fake-hardware',
+            driver_internal_info=driver_internal_info,
+            deploy_step={})
+        mock_execute.return_value = None
+
+        task = task_manager.TaskManager(self.context, node.uuid)
+        task.process_event('deploy')
+
+        deployments.do_next_deploy_step(task, 1, self.service.conductor.id)
+
+        # Deploying should be complete
+        node.refresh()
+        self.assertEqual(states.ACTIVE, node.provision_state)
+        self.assertEqual(states.NOSTATE, node.target_provision_state)
+        self.assertEqual({}, node.deploy_step)
+        self.assertNotIn('deploy_step_index', node.driver_internal_info)
+        self.assertIsNone(node.driver_internal_info['deploy_steps'])
+        mock_execute.assert_has_calls = [mock.call(self.deploy_steps[0]),
+                                         mock.call(self.deploy_steps[1])]
+        self.assertEqual('url', node.driver_internal_info['agent_url'])
+        self.assertEqual('token',
+                         node.driver_internal_info['agent_secret_token'])
 
     @mock.patch.object(conductor_utils, 'LOG', autospec=True)
     @mock.patch('ironic.drivers.modules.fake.FakeDeploy.execute_deploy_step',
