@@ -1184,17 +1184,20 @@ class ErrorHandlersTestCase(tests_base.TestCase):
     @mock.patch.object(conductor_utils, 'LOG')
     def test_spawn_rescue_error_handler_no_worker(self, log_mock):
         exc = exception.NoFreeConductorWorker()
-        self.node.instance_info = {'rescue_password': 'pass'}
+        self.node.instance_info = {'rescue_password': 'pass',
+                                   'hashed_rescue_password': '12'}
         conductor_utils.spawn_rescue_error_handler(exc, self.node)
         self.node.save.assert_called_once_with()
         self.assertIn('No free conductor workers', self.node.last_error)
         self.assertTrue(log_mock.warning.called)
         self.assertNotIn('rescue_password', self.node.instance_info)
+        self.assertNotIn('hashed_rescue_password', self.node.instance_info)
 
     @mock.patch.object(conductor_utils, 'LOG')
     def test_spawn_rescue_error_handler_other_error(self, log_mock):
         exc = Exception('foo')
-        self.node.instance_info = {'rescue_password': 'pass'}
+        self.node.instance_info = {'rescue_password': 'pass',
+                                   'hashed_rescue_password': '12'}
         conductor_utils.spawn_rescue_error_handler(exc, self.node)
         self.assertFalse(self.node.save.called)
         self.assertFalse(log_mock.warning.called)
@@ -1686,33 +1689,30 @@ class MiscTestCase(db_base.DbTestCase):
     @mock.patch.object(rpcapi.ConductorAPI, 'continue_node_deploy',
                        autospec=True)
     @mock.patch.object(rpcapi.ConductorAPI, 'get_topic_for', autospec=True)
-    def test__notify_conductor_resume_operation(self, mock_topic,
-                                                mock_rpc_call):
+    def test_notify_conductor_resume_operation(self, mock_topic,
+                                               mock_rpc_call):
         mock_topic.return_value = 'topic'
         with task_manager.acquire(
                 self.context, self.node.uuid, shared=False) as task:
-            conductor_utils._notify_conductor_resume_operation(
-                task, 'deploying', 'continue_node_deploy')
+            conductor_utils.notify_conductor_resume_operation(task, 'deploy')
             mock_rpc_call.assert_called_once_with(
                 mock.ANY, task.context, self.node.uuid, topic='topic')
 
-    @mock.patch.object(conductor_utils, '_notify_conductor_resume_operation',
+    @mock.patch.object(conductor_utils, 'notify_conductor_resume_operation',
                        autospec=True)
     def test_notify_conductor_resume_clean(self, mock_resume):
         with task_manager.acquire(
                 self.context, self.node.uuid, shared=False) as task:
             conductor_utils.notify_conductor_resume_clean(task)
-            mock_resume.assert_called_once_with(
-                task, 'cleaning', 'continue_node_clean')
+            mock_resume.assert_called_once_with(task, 'clean')
 
-    @mock.patch.object(conductor_utils, '_notify_conductor_resume_operation',
+    @mock.patch.object(conductor_utils, 'notify_conductor_resume_operation',
                        autospec=True)
     def test_notify_conductor_resume_deploy(self, mock_resume):
         with task_manager.acquire(
                 self.context, self.node.uuid, shared=False) as task:
             conductor_utils.notify_conductor_resume_deploy(task)
-            mock_resume.assert_called_once_with(
-                task, 'deploying', 'continue_node_deploy')
+            mock_resume.assert_called_once_with(task, 'deploy')
 
     @mock.patch.object(time, 'sleep', autospec=True)
     @mock.patch.object(fake.FakePower, 'get_power_state', autospec=True)
@@ -2018,3 +2018,36 @@ class GetNodeNextStepsTestCase(db_base.DbTestCase):
         with task_manager.acquire(self.context, node.uuid) as task:
             step_index = conductor_utils.get_node_next_clean_steps(task)
             self.assertEqual(0, step_index)
+
+
+class AgentTokenUtilsTestCase(tests_base.TestCase):
+
+    def setUp(self):
+        super(AgentTokenUtilsTestCase, self).setUp()
+        self.node = obj_utils.get_test_node(self.context,
+                                            driver='fake-hardware')
+
+    def test_add_secret_token(self):
+        self.assertNotIn('agent_secret_token', self.node.driver_internal_info)
+        conductor_utils.add_secret_token(self.node)
+        self.assertIn('agent_secret_token', self.node.driver_internal_info)
+
+    def test_wipe_deploy_internal_info(self):
+        conductor_utils.add_secret_token(self.node)
+        self.assertIn('agent_secret_token', self.node.driver_internal_info)
+        conductor_utils.wipe_deploy_internal_info(mock.Mock(node=self.node))
+        self.assertNotIn('agent_secret_token', self.node.driver_internal_info)
+
+    def test_is_agent_token_present(self):
+        # This should always be False as the token has not been added yet.
+        self.assertFalse(conductor_utils.is_agent_token_present(self.node))
+        conductor_utils.add_secret_token(self.node)
+        self.assertTrue(conductor_utils.is_agent_token_present(self.node))
+
+    def test_is_agent_token_supported(self):
+        self.assertTrue(
+            conductor_utils.is_agent_token_supported('6.1.1.dev39'))
+        self.assertTrue(
+            conductor_utils.is_agent_token_supported('6.2.1'))
+        self.assertFalse(
+            conductor_utils.is_agent_token_supported('6.0.0'))
