@@ -18,7 +18,6 @@ import types
 
 import mock
 from oslo_config import cfg
-from oslo_utils import uuidutils
 from testtools import matchers
 
 from ironic.common import exception
@@ -67,7 +66,7 @@ class TestPortObject(db_base.DbTestCase, obj_utils.SchemasTestMixIn):
 
             port = objects.Port.get(self.context, address)
 
-            mock_get_port.assert_called_once_with(address)
+            mock_get_port.assert_called_once_with(address, owner=None)
             self.assertEqual(self.context, port._context)
 
     def test_get_bad_id_and_uuid_and_address(self):
@@ -334,48 +333,3 @@ class TestConvertToVersion(db_base.DbTestCase):
         port._convert_to_version("1.8", False)
         self.assertFalse(port.is_smartnic)
         self.assertNotIn('is_smartnic', port.obj_get_changes())
-
-
-class TestMigrateVifPortId(db_base.DbTestCase):
-
-    def setUp(self):
-        super(TestMigrateVifPortId, self).setUp()
-        self.vif_id = 'some_uuid'
-        self.db_ports = []
-        extra = {'vif_port_id': self.vif_id}
-        for i in range(3):
-            port = db_utils.create_test_port(
-                uuid=uuidutils.generate_uuid(),
-                address='52:54:00:cf:2d:3%s' % i,
-                extra=extra, version='1.7')
-            self.db_ports.append(port)
-
-    @mock.patch.object(objects.Port, '_convert_to_version', autospec=True)
-    def test_migrate_vif_port_id_all(self, mock_convert):
-        with mock.patch.object(self.dbapi, 'get_not_versions',
-                               autospec=True) as mock_get_not_versions:
-            mock_get_not_versions.return_value = self.db_ports
-            total, done = objects.port.migrate_vif_port_id(self.context, 0)
-            self.assertEqual(3, total)
-            self.assertEqual(3, done)
-            mock_get_not_versions.assert_called_once_with('Port', ['1.8',
-                                                                   '1.9'])
-            calls = 3 * [
-                mock.call(mock.ANY, '1.9', remove_unavailable_fields=False),
-            ]
-            self.assertEqual(calls, mock_convert.call_args_list)
-
-    @mock.patch.object(objects.Port, '_convert_to_version', autospec=True)
-    def test_migrate_vif_port_id_one(self, mock_convert):
-        with mock.patch.object(self.dbapi, 'get_not_versions',
-                               autospec=True) as mock_get_not_versions:
-            mock_get_not_versions.return_value = self.db_ports
-            total, done = objects.port.migrate_vif_port_id(self.context, 1)
-            self.assertEqual(3, total)
-            self.assertEqual(1, done)
-            mock_get_not_versions.assert_called_once_with('Port', ['1.8',
-                                                                   '1.9'])
-            calls = [
-                mock.call(mock.ANY, '1.9', remove_unavailable_fields=False),
-            ]
-            self.assertEqual(calls, mock_convert.call_args_list)
